@@ -58,15 +58,15 @@ def handle_history_data(report_dir, test_result):
     try:
         with open(os.path.join(report_dir, 'history.json'), 'r', encoding='utf-8') as f:
             history = json.load(f)
-    except FileNotFoundError as e:
+    except:
         history = []
-    history.append({'passed': test_result['passed'],
+    history.append({'success': test_result['passed'],
                     'all': test_result['all'],
-                    'failed': test_result['failed'],
-                    'skipped': test_result['skipped'],
+                    'fail': test_result['failed'],
+                    'skip': test_result['skipped'],
                     'error': test_result['error'],
-                    'run_time': test_result['run_time'],
-                    'start_time': test_result['start_time'],
+                    'runtime': test_result['run_time'],
+                    'begin_time': test_result['begin_time'],
                     'pass_rate': test_result['pass_rate'],
                     })
 
@@ -74,6 +74,7 @@ def handle_history_data(report_dir, test_result):
         json.dump(history, f, ensure_ascii=True)
     return history
 
+
 def pytest_sessionfinish(session):
     """在整个测试运行完成之后调用的钩子函数,可以在此处生成测试报告"""
     report2 = session.config.getoption('--report')
@@ -82,7 +83,7 @@ def pytest_sessionfinish(session):
         test_result['title'] = session.config.getoption('--title') or '测试报告'
         test_result['tester'] = session.config.getoption('--tester') or '小测试'
         test_result['desc'] = session.config.getoption('--desc') or '无'
-        templates_name = session.config.getoption('--templates') or '1'
+        templates_name = session.config.getoption('--template') or '1'
         name = report2
     else:
         return
@@ -118,7 +119,6 @@ def pytest_sessionfinish(session):
         f.write(report.encode('utf8'))
 
 
-
 @pytest.hookimpl(tryfirst=True, hookwrapper=True)
 def pytest_runtest_makereport(item, call):
     outcome = yield
@@ -170,4 +170,4 @@ def pytest_addoption(parser):
         metavar="path",
         default=None,
         help="pytest-testreport Generate a template of the report",
-    )
\ No newline at end of file
+    )
